@@ -131,10 +131,9 @@ zenity_password_dialog (ZenityData *data, ZenityPasswordData *password_data)
 
 	if (data->timeout_delay > 0)
 	{
-		g_timeout_add_seconds (data->timeout_delay,
-			(GSourceFunc) zenity_util_timeout_handle,
-			dialog);
+		ZENITY_UTIL_SETUP_TIMEOUT (dialog)
 	}
+
 	zenity_util_gapp_main (GTK_WINDOW(dialog));
 }
 
@@ -142,16 +141,18 @@ static void
 zenity_password_dialog_response (GtkWidget *widget, char *rstr, gpointer data)
 {
 	ZenityPasswordData *password_data = data;
-	GtkEntryBuffer *user_buff, *pass_buff;
-	ZenityExitCode response = zenity_util_parse_dialog_response (rstr);
+	GtkEntryBuffer *user_buff = NULL, *pass_buff = NULL;
+	int response = zenity_util_parse_dialog_response (rstr);
+
+	if (password_data->username)
+		user_buff = gtk_entry_get_buffer (GTK_ENTRY(password_data->entry_username));
 
-	user_buff = gtk_entry_get_buffer (GTK_ENTRY(password_data->entry_username));
 	pass_buff = gtk_entry_get_buffer (GTK_ENTRY(password_data->entry_password));
 
 	switch (response)
 	{
 		case ZENITY_OK:
-			zenity_util_exit_code_with_data (ZENITY_OK, zen_data);
+			zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
 			if (password_data->username) {
 				g_print ("%s|%s\n",
 					gtk_entry_buffer_get_text (user_buff),
@@ -171,11 +172,12 @@ zenity_password_dialog_response (GtkWidget *widget, char *rstr, gpointer data)
 			zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
 			break;
 
+		case ZENITY_TIMEOUT:
+			zen_data->exit_code = zenity_util_return_exit_code (ZENITY_TIMEOUT);
+			break;
+
 		default:
-			if (zen_data->extra_label &&
-				response < (int)g_strv_length (zen_data->extra_label))
-				printf ("%s\n", zen_data->extra_label[response]);
-			zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
+			ZENITY_UTIL_RESPONSE_HANDLE_EXTRA_BUTTONS
 			break;
 	}
 	zenity_util_gapp_quit (GTK_WINDOW(widget), zen_data);
